Package: rhinotypeR
Type: Package
Title: Rhinovirus genotyping
Version: 1.6.0
Date: 2026-04-28
Authors@R: c(
    person("Martha", "Luka", role = c("aut", "cre"), email = "marthaluka20@gmail.com",
           comment = c(ORCID = "0000-0001-6217-4426")),
    person("Ruth", "Nanjala", role = c("aut")),
    person("Winfred", "Gatua", role = c("aut")),
    person("Wafaa M.", "Rashed", role = c("aut")),
    person("Olaitan", "Awe", role = c("aut"))
    )
Description: "rhinotypeR" is designed to automate the comparison of sequence data against prototype strains, 
            streamlining the genotype assignment process. By implementing predefined pairwise distance thresholds, 
            this package makes genotype assignment accessible to researchers and public health professionals. 
            This tool enhances our epidemiological toolkit by enabling more efficient surveillance and analysis of 
            rhinoviruses (RVs) and other viral pathogens with complex genomic landscapes. 
            Additionally, "rhinotypeR" supports comprehensive visualization and analysis of 
            single nucleotide polymorphisms (SNPs) and amino acid substitutions, 
            facilitating in-depth genetic and evolutionary studies.
License: MIT + file LICENSE
Encoding: UTF-8
Imports: Biostrings, methods, MSA2dist, msa
LazyData: false
biocViews: Sequencing, Genetics, Phylogenetics, Visualization,
        MultipleSequenceAlignment, MultipleComparison
Depends: R (>= 4.5.0)
Suggests: knitr, rmarkdown, BiocManager, BiocStyle, testthat (>= 3.0.0)
VignetteBuilder: knitr
Vignettes: `Introduction to rhinotypeR` = "vignettes/rhinotypeR.Rmd"
URL: https://github.com/omicscodeathon/rhinotypeR
BugReports: https://github.com/omicscodeathon/rhinotypeR/issues
RoxygenNote: 7.3.3
Config/testthat/edition: 3
git_url: https://git.bioconductor.org/packages/rhinotypeR
git_branch: RELEASE_3_23
git_last_commit: fe38fc1
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-29 00:12:21 UTC; biocbuild
Author: Martha Luka [aut, cre] (ORCID: <https://orcid.org/0000-0001-6217-4426>),
  Ruth Nanjala [aut],
  Winfred Gatua [aut],
  Wafaa M. Rashed [aut],
  Olaitan Awe [aut]
Maintainer: Martha Luka <marthaluka20@gmail.com>
